pandas-compat
=============

|Build Status| |Version Status|

**pandas-compat** is a package providing an API compatibility across versions to downstream libraries that use pandas.

This compatibility layer requires ``pandas`` >= 0.17.0.


Installation
------------


Install latest release version via conda
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. code-block:: shell

   $ conda install pandas-compat --channel conda-forge

Install latest release version via pip
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. code-block:: shell

   $ pip install pandas-compat

Install latest development version
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. code-block:: shell

    $ pip install git+https://github.com/pandas-compat/pandas-compat.git


Usage
-----

In your downstream library, you can use this pattern:

.. code-block:: python

   import pandas_compat as pdc

   pdc.is_datetime64tz_dtype(...)
   pdc.infer_dtype(...)


.. |Build Status| image:: https://travis-ci.org/pandas-dev/pandas-compat.svg?branch=master
   :target: https://travis-ci.org/pandas-dev/pandas-compat
.. |Version Status| image:: https://img.shields.io/pypi/v/pandas-compat.svg
   :target: https://pypi.python.org/pypi/pandas-compat/
